/**
 * RunningPromise is a utility class that helps manage the execution of an asynchronous function
 * at a specified polling interval. It allows starting, stopping, and checking the status of the
 * internally managed promise. The class also supports interrupting the polling process when stopped.
 */
export declare class RunningPromise {
    private fn;
    private pollingInterval;
    private running;
    private runningPromise;
    private interruptPromise;
    private interruptResolve;
    constructor(fn: () => Promise<void>, pollingInterval?: number);
    /**
     * Starts the running promise.
     */
    start(): void;
    /**
     * Stops the running promise, resolves any pending interruptible sleep,
     * and waits for the currently executing function to complete.
     */
    stop(): Promise<void>;
    /**
     * A sleep function that can be interrupted before the specified time.
     * The sleep duration is determined by 'timeInMs', and it can be terminated early if the 'interruptPromise' is resolved.
     * @param timeInMs - The time in milliseconds.
     */
    private interruptibleSleep;
    /**
     * Checks if the running promise is currently active.
     * @returns True if the promise is running.
     */
    isRunning(): boolean;
}
//# sourceMappingURL=index.d.ts.map